@@ -33,6 +33,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -60,6 +62,10 @@ class ManagedInstanceRole(
         :param managed_policies: The managed policies to apply to the role in addition to the default policies.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ManagedInstanceRole.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedInstanceRoleProps(
             domain_join_enabled=domain_join_enabled,
             managed_policies=managed_policies,
@@ -96,6 +102,11 @@ class ManagedInstanceRoleProps:
         :param managed_policies: The managed policies to apply to the role in addition to the default policies.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ManagedInstanceRoleProps.__init__)
+            check_type(argname="argument domain_join_enabled", value=domain_join_enabled, expected_type=type_hints["domain_join_enabled"])
+            check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
+            check_type(argname="argument ssm_management_enabled", value=ssm_management_enabled, expected_type=type_hints["ssm_management_enabled"])
         self._values: typing.Dict[str, typing.Any] = {}
         if domain_join_enabled is not None:
             self._values["domain_join_enabled"] = domain_join_enabled
